/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.common;

import javax.servlet.http.HttpSession ;
import javax.servlet.http.HttpSessionListener;
import javax.servlet.http.HttpSessionEvent;

/**
 * HttpSessionListener を実装した、セッション状態の監視リスナークラスです。
 * これは、セッションの作成/破棄を監視できます。
 * このリスナーは、WEB-INF/web.xml で、組み込みます。
 *
 * 【WEB-INF/web.xml】
 *
 *  &lt;listener&gt;
 *      &lt;listener-class&gt;
 *          org.opengion.hayabusa.common.HybsSessionListener
 *      &lt;/listener-class&gt;
 *  &lt;/listener&gt;
 *
 * @og.group ログイン制御
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class HybsSessionListener implements HttpSessionListener {

	/**
	 *  HttpSessionListener インターフェースの実装
	 *
	 * セッションが作成されたときにリスナーに通知される。
	 * 現段階では、なにもしない。
	 *
	 * @param event セッションイベント
	 */
	@Override
	public void sessionCreated( final HttpSessionEvent event ) {
	// taglib\HeadTag.java に移動
	//	HttpSession session = event.getSession();
	//	SystemManager.addSession( session );
	}

	/**
	 *  HttpSessionListener インターフェースの実装
	 *
	 * セッションが破棄されたときにリスナーに通知される。
	 *
	 * @param event セッションイベント
	 */
	@Override
	public void sessionDestroyed( final HttpSessionEvent event ) {
		HttpSession session = event.getSession();
		String sessionID = session.getId();
		SystemManager.removeSession( sessionID );
	}
}
